Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenloader/intern/readfile.c')
-rw-r--r--source/blender/blenloader/intern/readfile.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenloader/intern/readfile.c b/source/blender/blenloader/intern/readfile.c
index e3dc7c70697..2d8d9810b32 100644
--- a/source/blender/blenloader/intern/readfile.c
+++ b/source/blender/blenloader/intern/readfile.c
@@ -5867,8 +5867,8 @@ static void do_versions(FileData *fd, Library *lib, Main *main)
while (ob) {
prop= ob->prop.first;
while(prop) {
- if (prop->type == PROP_TIME) {
- // convert old PROP_TIME values from int to float
+ if (prop->type == GPROP_TIME) {
+ // convert old GPROP_TIME values from int to float
*((float *)&prop->data) = (float) prop->data;
}